html {
--doc-background-color: #C0C0C0;
--title-gradient-stop1: #D4D4D4;
--title-gradient-stop2: #E8E5E5;
--title-gradient-stop3: #EDECEC;
--title-gradient-stop4: #989696;
--title-border-color:   #808080;
--title-area-color:     #EBEBEB;
--title-shadow-color:   #F0F0F0;
--title-text-color:     #404040;
}

html.dark-mode {
--doc-background-color: #202020;
--title-gradient-stop1: #3A3A3A;
--title-gradient-stop2: #303030;
--title-gradient-stop3: #222222;
--title-gradient-stop4: #1C1C1C;
--title-border-color:   #505050;
--title-area-color:     #303030;
--title-shadow-color:   #101010;
--title-text-color:     #C0C0C0;
}

#projectalign
{
  vertical-align: bottom;
  padding-left: 5px;
}

#projectname
{
  font-size: 100%;
}

#projectlogo
{
  padding-left: 8px;
}

h1
{
  line-height: 1.2;
}

#doc-content
{
  background-color: var(--doc-background-color);
}

div.contents
{
  background-color: var(--page-background-color);
  border: 1px solid var(--toc-border-color);
  border-radius: 7px 7px 7px 7px;
}

div.header
{
  background: var(--title-gradient-stop1);
  background: linear-gradient(120deg, var(--title-gradient-stop1) 0%, var(--title-gradient-stop2) 30%, var(--title-gradient-stop3) 70%, var(--title-gradient-stop4) 100%);
  border-bottom: 1px solid var(--title-border-color);
}

#titlearea
{
  background: var(--title-area-color);
}

div.toc
{
  margin-right: 0px;
}

div.contents, div.headertitle
{
  padding: 8px;
}

div.headertitle
{
  text-shadow: 0px 2px 2px var(--title-shadow-color);
  color: var(--title-text-color);
}

div.headertitle .title
{
  line-height: 38px;
}

div.contents {
  padding-left: 12px;
  padding-right: 12px;
}

@media(min-width: 1120px) {

div.contents, div.headertitle
{
  width: 800px;
  margin-left: auto;
  margin-right: auto;
}

} /* end @media */


body {
    scrollbar-color: var(--scrollbar-thumb-color) var(--scrollbar-background-color);
}

::-webkit-scrollbar {
        background-color: var(--scrollbar-background-color);
        height: 12px;
        width: 12px;
}
::-webkit-scrollbar-thumb {
        border-radius: 6px;
        box-shadow: inset 0 0 12px 12px var(--scrollbar-thumb-color);
        border: solid 2px transparent;
}
::-webkit-scrollbar-corner {
        background-color: var(--scrollbar-background-color);
}


