namespace NS
{
  enum ED {
    ED1,
    ED2
  };
}

/**
 * @namespace NS
 *
 * @ingroup D
 *
 * Namespace NS.
 */

/**
 * @defgroup D D
 */

namespace NS
{
/**
 * @enum ED
 *
 * @ingroup D
 *
 * Enum ED.
 */

/**
 * @var ED ED::ED1
 *
 * Enumerator ED1.
 */

/**
 * @var ED ED::ED2
 *
 * Enumerator ED2.
 */
}
