// objective: C# property initializer
// check: class_class1.xml
///
/// Documentation of the class
class Class1
{
  public int Property1 { get; } = 1; ///< Documentation of first property
  public string Property2 { get; set; } ///< Documentation of second property
}
